<?php

/* Cette classe permet d'afficher une aide stocke dans un fichier XML.
   L'aide est affiche entirement avec ses chapitres et son contenu.
   Il est possible d'ouvrir l'aide directement dans un contexte en indiquant soit le nom du chapitre de niveau 1,
   soit le nom du chapitre de niveau 2, soit le nom du chapitre de niveau 3, soit le titre d'un article, soit
   un mot-cl de recherche (dans ce cas, on affichera une liste des rsultats trouvs redirigeant sur des articles).
   Pour viter des problmes avec des titres de niveaux similaires, il est indispensable d'indiquer les noms des
   chapitres parents (si le nom du chapitre de niveau 2 est prcis, le nom du chapitre de niveau 1 doit l'tre aussi).
   Le fichier XML doit tre format de cette manire :
	Une aide peut ne pas avoir de chapitres, dans ce cas, les articles sont directement placs au premier niveau
	Dans le cas de chapitre, les articles se situent toujours au bout des chapitres les plus profonds.

	<?xml version="1.0" encoding="iso-8859-1" ?>
	<aide>
		<titre>
			<fr>Aide du module Suivi de tickets</fr>
			<en>Documentation of the addon TroubleTickets</en>
		</titre>
		<auteur>
			<fr>Cantico</fr>
			<en>Cantico</en>
		</auteur>
		<description>
			<fr>Ceci est l'aide du module Suivi de tickets</fr>
		</description>
		<dernieremiseajour>13-12-2008</dernieremiseajour>
		<chapitresniveau1>
			<chapitreniveau1>
				<titre>
					<fr>Administration du module</fr>
				</titre>
				<chapitresniveau2>
					<chapitreniveau2>
						<titre>
							<fr>Droits d'accs des gestionnaires</fr>
						</titre>
						<chapitresniveau3>
							<chapitreniveau3>
								<titre>
									<fr>Administration du module</fr>
								</titre>
								<articles>
									<article>
										<titre>
											<fr>Article sans chapitre</fr>
										</titre>
										<texte>
											<fr></fr>
										</texte>
									</article>
								</articles>
							</chapitreniveau3>
						</chapitresniveau3>
					</chapitreniveau2>
				</chapitresniveau2>
			</chapitreniveau1>
		</chapitresniveau1>
		<articles>
			<article>
				<titre>
					<fr>Article sans chapitre</fr>
				</titre>
				<texte>
					<fr></fr>
				</texte>
			</article>
		</articles>
	</aide>
	
	Pour insrer une image dans le texte XML, il faut ajouter cette balise <image largeur="70" hauteur="50">representation.jpg</image>
	L'aide ira rechercher l'image dans le chemin indiqu dans cette classe : $cheminimages.
	Si les paramtres de largeur ou d'hauteur sont prciss, l'image sera redimensionne.
 */

class TroubleTickets_Aide {
	
	//Variables
	var $cheminfichierxml;
	var $cheminimages; /* Chemin o se situent les images */
	var $urlaffichage; /* url d'affichage de l'aide : utilis lors de l'affichage afin d'ajouter des urls */
	var $langue; /* fr ou en */
	var $nomchapitreniveau1;
	var $nomchapitreniveau2;
	var $nomchapitreniveau3;
	var $titrearticle;
	var $recherche;
	var $xml; /* Objet SimpleXMLElement utilis dans les fonctions */
	
	//Constructeur
	function __construct($cheminfichierxml='aide.xml', $cheminimages='images', $urlaffichage='', $langue='fr', $nomchapitreniveau1='', $nomchapitreniveau2='', $nomchapitreniveau3='', $titrearticle='', $recherche='') {
		$this->cheminfichierxml = $cheminfichierxml;
		$this->cheminimages = $cheminimages;
		$this->urlaffichage = $urlaffichage;
		$this->langue = $langue;
		$this->nomchapitreniveau1 = $nomchapitreniveau1;
		$this->nomchapitreniveau2 = $nomchapitreniveau2;
		$this->nomchapitreniveau3 = $nomchapitreniveau3;
		$this->titrearticle = $titrearticle;
		$this->recherche = $recherche;
		
		/* Utilise les classes SimpleXML pour rcuprer le contenu */
		$this->xml = simplexml_load_file($this->cheminfichierxml); //Convertit le fichier en un objet de type SimpleXMLElement
	}
	
	/* Retourne les informations principales de l'aide : titre, description, date de dernire mise  jour, auteur */
	function informationsgenerales() {
		$infos = array();
		$infos['titre'] = '';
		$infos['description'] = '';
		$infos['auteur'] = '';
		$infos['datedernieremiseajour'] = '';
		if ($this->xml !== false) {
			if ($this->langue == 'fr') {
	    		if (isset($this->xml->titre)) {
	    			if (isset($this->xml->titre->fr)) {
	    				$infos['titre'] = utf8_decode($this->xml->titre->fr);
	    			}
	    		}
	    		if (isset($this->xml->description)) {
	    			if (isset($this->xml->description->fr)) {
	    				$infos['description'] = utf8_decode($this->xml->description->fr);
	    			}
	    		}
	    		if (isset($this->xml->auteur)) {
	    			if (isset($this->xml->auteur->fr)) {
	    				$infos['auteur'] = utf8_decode($this->xml->auteur->fr);
	    			}
	    		}
	    		if (isset($this->xml->datedernieremiseajour)) {
	    			if (isset($this->xml->datedernieremiseajour->fr)) {
	    				$infos['datedernieremiseajour'] = utf8_decode($this->xml->datedernieremiseajour->fr);
	    			}
	    		}
			}
			if ($this->langue == 'en') {
	    		if (isset($this->xml->titre)) {
	    			if (isset($this->xml->titre->en)) {
	    				$infos['titre'] = utf8_decode($this->xml->titre->en);
	    			}
	    		}
	    		if (isset($this->xml->description)) {
	    			if (isset($this->xml->description->en)) {
	    				$infos['description'] = utf8_decode($this->xml->description->en);
	    			}
	    		}
	    		if (isset($this->xml->auteur)) {
	    			if (isset($this->xml->auteur->en)) {
	    				$infos['auteur'] = utf8_decode($this->xml->auteur->en);
	    			}
	    		}
	    		if (isset($this->xml->datedernieremiseajour)) {
	    			if (isset($this->xml->datedernieremiseajour->en)) {
	    				$infos['datedernieremiseajour'] = utf8_decode($this->xml->datedernieremiseajour->en);
	    			}
	    		}
			}
		}
		return $infos;
	}
	
	/* Retourne la liste des chapitres de niveau 1 sous la forme d'objets TroubleTickets_AideChapitre */
	function chapitresniveau1() {
		$chapitres = array();
		if ($this->xml !== false) {
    		if (isset($this->xml->chapitresniveau1)) {
    			foreach ($this->xml->chapitresniveau1->chapitreniveau1 as $chapitre) {
    				if (isset($chapitre->titre)) {
    					if ($this->langue == 'fr') {
	    					if (isset($chapitre->titre->fr)) {
	    						$chapitres[] = new TroubleTickets_AideChapitre($chapitre, 1, '', '', utf8_decode($chapitre->titre->fr), 'fr');
	    					}
    					}
    					if ($this->langue == 'en') {
	    					if (isset($chapitre->titre->en)) {
	    						$chapitres[] = new TroubleTickets_AideChapitre($chapitre, 1, '', '', utf8_decode($chapitre->titre->en), 'en');
	    					}
    					}
    				}
    			}
    		}
		}
		return $chapitres;
	}
	
	/* Retourne les articles  la racine de l'aide, dans le cas o il n'y a pas de chapitres de niveaux 1 */
	function articles() {
		$articles = array();
		if (count($this->chapitresniveau1()) == 0) {
			if ($this->xml !== false) {
	    		if (isset($this->xml->articles)) {
	    			foreach ($this->xml->articles->article as $article) {
	    				if (isset($article->titre)) {
	    					if ($this->langue == 'fr') {
		    					if (isset($article->titre->fr) && isset($article->texte->fr)) {
		    						$articles[] = new TroubleTickets_AideArticle($article, '', 0, utf8_decode($article->titre->fr), utf8_decode($article->texte->fr), 'fr');
		    					}
	    					}
	    					if ($this->langue == 'en') {
		    					if (isset($article->titre->en) && isset($article->texte->en)) {
		    						$articles[] = new TroubleTickets_AideArticle($article, '', 0, utf8_decode($article->titre->en), utf8_decode($article->texte->en), 'en');
		    					}
	    					}
	    				}
	    			}
	    		}
			}
		}
		return $articles;
	}
	
	/* Retourne le contenu complet de l'aide selon le contexte */
	function contenu() {
		$html = '';
		$infos = $this->informationsgenerales();
		$chapitresniveau1 = $this->chapitresniveau1();
		/* Titre et description de l'aide */
		$html .= '<table class="troubletickets_aidebandeau" cellpadding="0" cellspacing="0" width="100%">
					<tr>
						<td align="left" width="33%">';
				$html .= '<div class="troubletickets_aidebandeautitre"><h1>'.$infos['titre'].'</h1></div>
						</td>
						<td align="center" width="33%">
							<div class="troubletickets_aidebandeaurecherche">
								<form>
									<input name="recherche" type="text" value="" />
									<input type="submit" value="Rechercher" />
								</form>
							</div>
						</td>
						<td align="right" width="33%">';
		if ($infos['description'] != '') {
				$html .= '<div class="troubletickets_aidebandeaudescription">'.$infos['description'].'</div>
						</td>
					</tr>';
		}
		$html .= '</table>';		
		/* S'il n'y a pas de chapitres, on cherche des articles  la racine */
		if (count($chapitresniveau1) == 0) {
			/* Articles  la racine du site : pas de sommaire  gauche */
			$html .= '<div class="troubletickets_aidecorps100">&nbsp;';
			$html .= '</div>';
			
		} else {
			/* Sommaire : chapitres de niveau 1 : toujours affichs */
			$html .= '<div class="troubletickets_aidesectiongauche">&nbsp;';
				for ($i=0;$i<=count($chapitresniveau1)-1;$i++) {
					$html .= '<div class="troubletickets_aidechapitreniveau1">';
						$html .= '<a href="'.$this->urlaffichage.'&amp;langue='.$this->langue.'&amp;nomchapitreniveau1='.urlencode($chapitresniveau1[$i]->nom).'">'.$chapitresniveau1[$i]->nom.'</a>';
					$html .= '</div>';
				}
			$html .= '</div>';
			
			/* Corps de la page : sommaire chapitres niveaux 2 et 3 et articles.
			 * Le corps s'affiche selon les paramtres de recherche : nomchapitreniveau1, nomchapitreniveau2, nomchapitreniveau3, titrearticle, recherche */
			$html .= '<div class="troubletickets_aidecorps75">&nbsp;';
			if ($this->recherche != '') {
				/* On affiche une page spciale affichant une liste de liens vers des articles contenant dans le titre ou le contenu la valeur de la recherche */
				$html .= "Liste d'articles correspondant  la valeur de la recherche";
			} else {
				if ($this->nomchapitreniveau1 != '') {
					/* On affiche le contenu du chapitre 1 */
					
					/* Titre du chapitre 1 */
					$html .= '<div class="troubletickets_aidetitrechapitreniveau1">'.$this->nomchapitreniveau1.'</div>';
					
					/* Sommaire */
					$chapitresniveaux2 = array();
					$chapitresniveaux3 = array();
					for ($i=0;$i<=count($chapitresniveau1)-1;$i++) {
						/* On recherche le chapitre de niveau 1 */
						if ($chapitresniveau1[$i]->nom == $this->nomchapitreniveau1) {
							/* Liste des chapitres de niveaux 2 */
							$chapitresniveaux2 = $chapitresniveau1[$i]->souschapitres();
							$html .= '<ul class="troubletickets_aidesommairechapitresniveaux2">';
							for ($j=0;$j<=count($chapitresniveaux2)-1;$j++) {
								$html .= '<li class="troubletickets_aidesommairechapitreniveau2">'.$chapitresniveaux2[$j]->nom;
								/* Liste des chapitres de niveaux 3 */
								$chapitresniveaux3 = $chapitresniveaux2[$i]->souschapitres();
								$html .= '<ul class="troubletickets_aidesommairechapitresniveaux3">';
								for ($k=0;$k<=count($chapitresniveaux3)-1;$k++) {
									$html .= '<li class="troubletickets_aidesommairechapitreniveau3">'.$chapitresniveaux3[$k]->nom;
									
									$html .= '</li>';
								}
								$html .= '</ul>';
								$html .= '</li>';
							}
							$html .= '</ul>';
						}
					}
					
					/* Affichage des articles */
					for ($i=0;$i<=count($chapitresniveau1)-1;$i++) {
						/* On recherche le chapitre de niveau 1 */
						if ($chapitresniveau1[$i]->nom == $this->nomchapitreniveau1) {
							/* Liste des chapitres de niveaux 2 */
							$chapitresniveaux2 = $chapitresniveau1[$i]->souschapitres();
							$html .= '<div class="troubletickets_aideaffichagechapitresniveaux2">';
							for ($j=0;$j<=count($chapitresniveaux2)-1;$j++) {
								$html .= '<div class="troubletickets_aideaffichagechapitreniveau2">'.$chapitresniveaux2[$j]->nom;
								/* Liste des chapitres de niveaux 3 */
								$chapitresniveaux3 = $chapitresniveaux2[$i]->souschapitres();
								$html .= '<div class="troubletickets_aideaffichagechapitresniveaux3">';
								for ($k=0;$k<=count($chapitresniveaux3)-1;$k++) {
									$html .= '<div class="troubletickets_aideaffichagechapitreniveau3">'.$chapitresniveaux3[$k]->nom;
									
									$html .= '</div>';
									/* Liste des articles au niveau 3 */
									$articlesniveau3 = $chapitresniveau3[$i]->articles();
									$html .= '<div class="troubletickets_aideaffichagearticlesniveau3">';
									for ($l=0;$l<=count($articlesniveau3)-1;$l++) {
										/* Titre de l'article */
										$html .= '<div class="troubletickets_aideaffichagearticletitre">'.$articlesniveau3[$l]->titre.'</div>';
										/* Texte de l'article */
										$html .= '<div class="troubletickets_aideaffichagearticletexte">'.$articlesniveau3[$l]->texte.'</div>';
									}
									$html .= '</div>';
								}
								$html .= '</ul>';
								$html .= '</div>';
								/* Liste des articles au niveau 2 */
								$articlesniveau2 = $chapitresniveaux2[$i]->articles();
								$html .= '<div class="troubletickets_aideaffichagearticlesniveau2">';
								for ($l=0;$l<=count($articlesniveau2)-1;$l++) {
									/* Titre de l'article */
									$html .= '<div class="troubletickets_aideaffichagearticletitre">'.$articlesniveau2[$l]->titre.'</div>';
									/* Texte de l'article */
									$html .= '<div class="troubletickets_aideaffichagearticletexte">'.$articlesniveau2[$l]->texte.'</div>';
								}
								$html .= '</div>';
							}
							/* Liste des articles au niveau 1 */
							$articlesniveau1 = $chapitresniveau1[$i]->articles();
							$html .= '<div class="troubletickets_aideaffichagearticlesniveau1">';
							for ($l=0;$l<=count($articlesniveau1)-1;$l++) {
								/* Titre de l'article */
								$html .= '<div class="troubletickets_aideaffichagearticletitre">'.$articlesniveau1[$l]->titre.'</div>';
								/* Texte de l'article */
								$html .= '<div class="troubletickets_aideaffichagearticletexte">'.$articlesniveau1[$l]->texte.'</div>';
							}
							$html .= '</div>';
						}
					}
					
					/* Ajout d'un lien interne correspondant  l'endroit o afficher le haut de la page :
					 * en rapport  la valeur de recherche */
					if ($this->nomchapitreniveau2 != '' && $this->nomchapitreniveau3 != '' && $this->titrearticle != '') {
						
					}
				} else {
					/* On affiche rien */
				}
			}
			$html .= '</div>';
		}
		return $html;	
	}
	
}

?>
