<?php
/*
 * Rcupre un bug fourni par le web-services de MantisConnect et le formate
 * 
 * Description de l'objet retourn par MantisConnect :
 * 	<xsd:element name="id" type="xsd:integer" minOccurs="0"/>
 * 	<xsd:element name="view_state" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="last_updated" type="xsd:dateTime" minOccurs="0"/>
 * 	<xsd:element name="project" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="category" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="priority" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="severity" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="status" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="reporter" type="tns:AccountData" minOccurs="0"/>
 * 	<xsd:element name="summary" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="version" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="build" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="platform" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="os" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="os_build" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="reproducibility" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="date_submitted" type="xsd:dateTime" minOccurs="0"/>
 * 	<xsd:element name="sponsorship_total" type="xsd:integer" minOccurs="0"/>
 * 	<xsd:element name="handler" type="tns:AccountData" minOccurs="0"/>
 * 	<xsd:element name="projection" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="eta" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="resolution" type="tns:ObjectRef" minOccurs="0"/>
 * 	<xsd:element name="fixed_in_version" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="description" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="steps_to_reproduce" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="additional_information" type="xsd:string" minOccurs="0"/>
 * 	<xsd:element name="attachments" type="tns:AttachmentDataArray" minOccurs="0"/>
 * 	<xsd:element name="relationships" type="tns:RelationshipDataArray" minOccurs="0"/>
 * 	<xsd:element name="notes" type="tns:IssueNoteDataArray" minOccurs="0"/>
 * 	<xsd:element name="custom_fields" type="tns:CustomFieldValueForIssueDataArray" minOccurs="0"/>
 */
class TroubleTickets_MantisConnect_Bug {
	
	//Variables
	var $connexionMantis; /* objet TroubleTickets_MantisConnect */
	var $decodageUTF8actif; /* Si  vrai, on dcode tous les rsultats en UTF8 */
	var $id;
	var $titre;
	var $description;
	var $statut;
	var $droitsacces;
	var $responsable; /* Tableau : surnom, nom, mail */
	var $projet;
	var $date;
	var $datemiseajour;
	var $categorie;
	var $priorite;
	var $gravite;
	var $auteur; /* Tableau : surnom, nom, mail */
	var $resolution;
	var $versioncorrection;
	var $informationscomplementaires;
	var $urlmantis; /* Url pour accder aubug dans Mantis */
	
	//Constructeur
	function __construct(TroubleTickets_MantisConnect $connexionMantis, $id='') {
		$this->connexionMantis = $connexionMantis;
		$this->id = $id;		
	}
	
	/* Charge le bug */
	function charge() {
		if ($this->id != '') {
			$bug = $this->connexionMantis->bug($this->id);
			if ($bug === false) {
				return false;
			} else {
				/* Dcompose les informations du bug */
				$this->id = $bug->id;
				$this->titre = $bug->summary;
				$this->description = nl2br($bug->description);
				$this->statut = $bug->status->name;
				$this->droitsacces = $bug->view_state->name;
				$this->responsable = array();
				$this->responsable['surnom'] = $bug->handler->name;
				$this->responsable['nom'] = $bug->handler->real_name;
				$this->responsable['mail'] = $bug->handler->email;
				$this->projet = $bug->project->name;
				$this->date = $bug->date_submitted;
				$this->datemiseajour = $bug->last_updated;
				$this->categorie = $bug->category;
				$this->priorite = $bug->priority->name;
				$this->gravite = $bug->severity->name;
				$this->auteur = array();
				$this->auteur['surnom'] = $bug->reporter->name;
				$this->auteur['nom'] = $bug->reporter->real_name;
				$this->auteur['mail'] = $bug->reporter->email;
				$this->resolution = $bug->resolution->name;
				$this->versioncorrection = $bug->fixed_in_version;
				$this->informationscomplementaires = nl2br($bug->additional_information);
				
				/* Dcode en UTF8 */
				if ($this->connexionMantis->decodageUTF8actif) {
					$this->id = utf8_decode($this->id);
					$this->titre = utf8_decode($this->titre);
					$this->description = utf8_decode($this->description);
					$this->statut = utf8_decode($this->statut);
					$this->droitsacces = utf8_decode($this->droitsacces);
					$this->responsable['surnom'] = utf8_decode($this->responsable['surnom']);
					$this->responsable['nom'] = utf8_decode($this->responsable['nom']);
					$this->responsable['mail'] = utf8_decode($this->responsable['mail']);
					$this->projet = utf8_decode($this->projet);
					$this->date = utf8_decode($this->date);
					$this->datemiseajour = utf8_decode($this->datemiseajour);
					$this->categorie = utf8_decode($this->categorie);
					$this->priorite = utf8_decode($this->priorite);
					$this->gravite = utf8_decode($this->gravite);
					$this->auteur['surnom'] = utf8_decode($this->auteur['surnom']);
					$this->auteur['nom'] = utf8_decode($this->auteur['nom']);
					$this->auteur['mail'] = utf8_decode($this->auteur['mail']);
					$this->resolution = utf8_decode($this->resolution);
					$this->versioncorrection = utf8_decode($this->versioncorrection);
					$this->informationscomplementaires = utf8_decode($this->informationscomplementaires);
				}
				
				/* Tente de gnrer l'url d'accs au bug dans Mantis depuis */
				
			}
		}
	}
	
	/* Cr ou met  jour le bug */
	function enregistre() {
		if ($this->id == '') {
			/* On cr le nouveau bug dans Mantis */
			try {
				$connexion = new SoapClient($this->connexionMantis->url);
				$idbugcree = $connexion->__soapCall('mc_issue_add', array(
					'' => ''
					
				));
			} catch (SoapFault $fault) {
	    		bab_debug("SOAP Fault: faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring}");
				return false;
			}
			return $idbugcree;
		} else {
			/* On met  jour le bug dans Mantis */
			try {
				$connexion = new SoapClient($this->connexionMantis->url);
				$idbugcree = $connexion->__soapCall('mc_issue_update', array(
					'' => ''
					
				));
			} catch (SoapFault $fault) {
	    		bab_debug("SOAP Fault: faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring}");
				return false;
			}
			return true;
		}
	}
	
}

?>
